==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/parameter-contexts/ui/parameter-context-listing/parameter-context-listing.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { ParameterContextListing } from './parameter-context-listing.component';
import { provideMockStore } from '@ngrx/store/testing';
import { initialState } from '../../state/parameter-context-listing/parameter-context-listing.reducer';

describe('ParameterContextListing', () => {
    let component: ParameterContextListing;
    let fixture: ComponentFixture<ParameterContextListing>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            declarations: [ParameterContextListing],
            providers: [provideMockStore({ initialState })]
        });
        fixture = TestBed.createComponent(ParameterContextListing);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/parameter-contexts/ui/parameter-context-listing/parameter-context-listing.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { ParameterContextListing } from './parameter-context-listing.component';
import { provideMockStore } from '@ngrx/store/testing';
import { initialState } from '../../state/parameter-context-listing/parameter-context-listing.reducer';

describe('ParameterContextListing', () => {
    let component: ParameterContextListing;
    let fixture: ComponentFixture<ParameterContextListing>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            imports: [ParameterContextListing],
            providers: [provideMockStore({ initialState })]
        });
        fixture = TestBed.createComponent(ParameterContextListing);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});
